<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat window notifications</source>
        <translation>Wiadomość w oknie rozmowy</translation>
    </message>
</context>
</TS>